You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@phoenix.apache.org by ya...@apache.org on 2020/07/17 02:27:18 UTC

[phoenix] branch master updated: PHOENIX-5933 Rename VIEW_TTL property to be PHOENIX_TTL

This is an automated email from the ASF dual-hosted git repository.

yanxinyi pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/phoenix.git


The following commit(s) were added to refs/heads/master by this push:
     new 8f9ee50  PHOENIX-5933 Rename VIEW_TTL property to be PHOENIX_TTL
8f9ee50 is described below

commit 8f9ee5015f013de173a26161f34a270d68a9d2f9
Author: Jacob Isaac <ji...@salesforce.com>
AuthorDate: Thu Jul 16 12:42:38 2020 -0700

    PHOENIX-5933 Rename VIEW_TTL property to be PHOENIX_TTL
    
    Signed-off-by: Xinyi Yan <xy...@salesforce.com>
---
 .../java/org/apache/phoenix/end2end/ViewTTLIT.java | 128 +++++-----
 .../phoenix/coprocessor/MetaDataEndpointImpl.java  |  50 ++--
 .../coprocessor/generated/PTableProtos.java        | 266 ++++++++++-----------
 .../apache/phoenix/exception/SQLExceptionCode.java |   6 +-
 .../phoenix/jdbc/PhoenixDatabaseMetaData.java      |  16 +-
 .../phoenix/query/ConnectionQueryServicesImpl.java |   4 +-
 .../org/apache/phoenix/query/QueryConstants.java   |   4 +-
 .../org/apache/phoenix/schema/DelegateTable.java   |  10 +-
 .../org/apache/phoenix/schema/MetaDataClient.java  |  94 ++++----
 .../java/org/apache/phoenix/schema/PTable.java     |  12 +-
 .../java/org/apache/phoenix/schema/PTableImpl.java |  79 +++---
 .../org/apache/phoenix/schema/TableProperty.java   |  10 +-
 .../java/org/apache/phoenix/util/ViewUtil.java     |  14 +-
 phoenix-protocol/src/main/PTable.proto             |   6 +-
 14 files changed, 349 insertions(+), 350 deletions(-)

diff --git a/phoenix-core/src/it/java/org/apache/phoenix/end2end/ViewTTLIT.java b/phoenix-core/src/it/java/org/apache/phoenix/end2end/ViewTTLIT.java
index ee77b33..032ad11 100644
--- a/phoenix-core/src/it/java/org/apache/phoenix/end2end/ViewTTLIT.java
+++ b/phoenix-core/src/it/java/org/apache/phoenix/end2end/ViewTTLIT.java
@@ -61,13 +61,13 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
     private static final Logger LOGGER = LoggerFactory.getLogger(ViewTTLIT.class);
     private static final String ORG_ID_FMT = "00D0x000%s";
     private static final String ID_FMT = "00A0y000%07d";
-    private static final String VIEW_TTL_HEADER_SQL =  "SELECT VIEW_TTL FROM SYSTEM.CATALOG "
+    private static final String PHOENIX_TTL_HEADER_SQL =  "SELECT PHOENIX_TTL FROM SYSTEM.CATALOG "
             + "WHERE %s AND TABLE_SCHEM = '%s' AND TABLE_NAME = '%s' AND TABLE_TYPE = '%s'";
 
-    private static final String ALTER_VIEW_TTL_SQL = "ALTER VIEW %s.%s set VIEW_TTL=%d";
+    private static final String ALTER_PHOENIX_TTL_SQL = "ALTER VIEW %s.%s set PHOENIX_TTL=%d";
 
     // Scans the HBase rows directly for the view ttl related header rows column and asserts
-    private void assertViewHeaderRowsHaveViewTTLRelatedCells(String schemaName, long minTimestamp,
+    private void assertViewHeaderRowsHavePhoenixTTLRelatedCells(String schemaName, long minTimestamp,
             boolean rawScan, int expectedRows) throws IOException, SQLException {
 
         FilterList filterList = new FilterList(FilterList.Operator.MUST_PASS_ALL);
@@ -75,10 +75,10 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
                 CompareFilter.CompareOp.EQUAL,
                 new SubstringComparator(schemaName)
         );
-        QualifierFilter viewTTLQualifierFilter = new QualifierFilter(CompareFilter.CompareOp.EQUAL,
-                new BinaryComparator(PhoenixDatabaseMetaData.VIEW_TTL_BYTES));
+        QualifierFilter phoenixTTLQualifierFilter = new QualifierFilter(CompareFilter.CompareOp.EQUAL,
+                new BinaryComparator(PhoenixDatabaseMetaData.PHOENIX_TTL_BYTES));
         filterList.addFilter(schemaNameFilter);
-        filterList.addFilter(viewTTLQualifierFilter);
+        filterList.addFilter(phoenixTTLQualifierFilter);
         try (Table tbl = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES)
                 .getTable(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES)) {
 
@@ -91,7 +91,7 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
             for (Result result = scanner.next(); result != null; result = scanner.next()) {
                 numMatchingRows +=
                         result.containsColumn(QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES,
-                                PhoenixDatabaseMetaData.VIEW_TTL_BYTES) ? 1 : 0;
+                                PhoenixDatabaseMetaData.PHOENIX_TTL_BYTES) ? 1 : 0;
             }
             assertEquals(String.format("Expected rows do not match for table = %s at timestamp %d",
                     Bytes.toString(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES), minTimestamp), expectedRows, numMatchingRows);
@@ -99,13 +99,13 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
 
     }
 
-    private void assertSyscatHaveViewTTLRelatedColumns(String tenantId, String schemaName, String tableName, String tableType, long ttlValueExpected)
+    private void assertSyscatHavePhoenixTTLRelatedColumns(String tenantId, String schemaName, String tableName, String tableType, long ttlValueExpected)
             throws SQLException {
 
         try (Connection connection = DriverManager.getConnection(getUrl())) {
             Statement stmt = connection.createStatement();
             String tenantClause = tenantId == null || tenantId.isEmpty() ? "TENANT_ID IS NULL" : String.format("TENANT_ID = '%s'", tenantId);
-            String sql = String.format(VIEW_TTL_HEADER_SQL, tenantClause, schemaName, tableName, tableType);
+            String sql = String.format(PHOENIX_TTL_HEADER_SQL, tenantClause, schemaName, tableName, tableType);
             stmt.execute(sql);
             ResultSet rs = stmt.getResultSet() ;
             long actualTTLValueReturned = rs.next() ? rs.getLong(1) : 0;
@@ -127,7 +127,7 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
      */
 
     @Test
-    public void testWithBasicGlobalViewWithNoViewTTLDefined() throws Exception {
+    public void testWithBasicGlobalViewWithNoPhoenixTTLDefined() throws Exception {
 
         long startTime = System.currentTimeMillis();
 
@@ -141,14 +141,14 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
                 .build();
 
         // Expected 2 rows - one for Table and GlobalView each.
-        // Since the VIEW_TTL property values are not being set, we expect the view header columns to show up in raw scans only.
-        assertViewHeaderRowsHaveViewTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, true, 2);
+        // Since the PHOENIX_TTL property values are not being set, we expect the view header columns to show up in raw scans only.
+        assertViewHeaderRowsHavePhoenixTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, true, 2);
     }
 
 
 
     @Test
-    public void testViewTTLWithTableLevelTTLFails() throws Exception {
+    public void testPhoenixTTLWithTableLevelTTLFails() throws Exception {
 
         // Define the test schema.
         // 1. Table with default columns => (ORG_ID, KP, COL1, COL2, COL3), PK => (ORG_ID, KP)
@@ -159,7 +159,7 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         tableOptions.setTableProps("COLUMN_ENCODED_BYTES=0,MULTI_TENANT=true,TTL=100");
 
         TenantViewOptions tenantViewOptions = TenantViewOptions.withDefaults();
-        tenantViewOptions.setTableProps("VIEW_TTL=1000");
+        tenantViewOptions.setTableProps("PHOENIX_TTL=1000");
         try {
             schemaBuilder
                     .withTableOptions(tableOptions)
@@ -167,12 +167,12 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
                     .buildNewView();
             fail();
         } catch (SQLException e) {
-            assertEquals(SQLExceptionCode.CANNOT_SET_OR_ALTER_VIEW_TTL_FOR_TABLE_WITH_TTL.getErrorCode(), e.getErrorCode());
+            assertEquals(SQLExceptionCode.CANNOT_SET_OR_ALTER_PHOENIX_TTL_FOR_TABLE_WITH_TTL.getErrorCode(), e.getErrorCode());
         }
     }
 
     @Test
-    public void testViewTTLWithViewIndexFails() throws Exception {
+    public void testPhoenixTTLWithViewIndexFails() throws Exception {
 
         // Define the test schema.
         // 1. Table with default columns => (ORG_ID, KP, COL1, COL2, COL3), PK => (ORG_ID, KP)
@@ -183,7 +183,7 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         tableOptions.setTableProps("COLUMN_ENCODED_BYTES=0,MULTI_TENANT=true");
 
         TenantViewIndexOptions tenantViewIndexOptions = TenantViewIndexOptions.withDefaults();
-        tenantViewIndexOptions.setIndexProps("VIEW_TTL=1000");
+        tenantViewIndexOptions.setIndexProps("PHOENIX_TTL=1000");
         try {
             schemaBuilder
                     .withTableOptions(tableOptions)
@@ -192,12 +192,12 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
                     .buildNewView();
             fail();
         } catch (SQLException e) {
-            assertEquals(SQLExceptionCode.VIEW_TTL_SUPPORTED_FOR_VIEWS_ONLY.getErrorCode(), e.getErrorCode());
+            assertEquals(SQLExceptionCode.PHOENIX_TTL_SUPPORTED_FOR_VIEWS_ONLY.getErrorCode(), e.getErrorCode());
         }
     }
 
     @Test
-    public void testViewTTLForLevelOneView() throws Exception {
+    public void testPhoenixTTLForLevelOneView() throws Exception {
         long startTime = System.currentTimeMillis();
 
         // Define the test schema.
@@ -209,7 +209,7 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         tableOptions.setTableProps("COLUMN_ENCODED_BYTES=0,MULTI_TENANT=true");
 
         TenantViewOptions tenantViewOptions = TenantViewOptions.withDefaults();
-        tenantViewOptions.setTableProps("VIEW_TTL=1000");
+        tenantViewOptions.setTableProps("PHOENIX_TTL=1000");
         schemaBuilder
                 .withTableOptions(tableOptions)
                 .withTenantViewOptions(tenantViewOptions)
@@ -222,16 +222,16 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         String indexOnTenantViewName = String.format("IDX_%s", stripQuotes(schemaBuilder.getEntityKeyPrefix()));
 
         // Expected 2 rows - one for TenantView and ViewIndex each.
-        // Since the VIEW_TTL property values are being set, we expect the view header columns to show up in regular scans too.
-        assertViewHeaderRowsHaveViewTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, false, 2);
-        // Since the VIEW_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 1000);
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 1000);
+        // Since the PHOENIX_TTL property values are being set, we expect the view header columns to show up in regular scans too.
+        assertViewHeaderRowsHavePhoenixTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, false, 2);
+        // Since the PHOENIX_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 1000);
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 1000);
 
     }
 
     @Test
-    public void testViewTTLForLevelTwoView() throws Exception {
+    public void testPhoenixTTLForLevelTwoView() throws Exception {
         long startTime = System.currentTimeMillis();
 
         // Define the test schema.
@@ -245,7 +245,7 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
 
         PhoenixTestBuilder.SchemaBuilder.GlobalViewOptions
                 globalViewOptions = PhoenixTestBuilder.SchemaBuilder.GlobalViewOptions.withDefaults();
-        globalViewOptions.setTableProps("VIEW_TTL=300000");
+        globalViewOptions.setTableProps("PHOENIX_TTL=300000");
 
         PhoenixTestBuilder.SchemaBuilder.GlobalViewIndexOptions
                 globalViewIndexOptions =
@@ -253,7 +253,7 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         globalViewIndexOptions.setLocal(false);
 
         TenantViewOptions tenantViewWithOverrideOptions = TenantViewOptions.withDefaults();
-        tenantViewWithOverrideOptions.setTableProps("VIEW_TTL=1000");
+        tenantViewWithOverrideOptions.setTableProps("PHOENIX_TTL=1000");
         schemaBuilder
                 .withTableOptions(tableOptions)
                 .withGlobalViewOptions(globalViewOptions)
@@ -270,13 +270,13 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         String indexOnTenantViewName = String.format("IDX_%s", stripQuotes(schemaBuilder.getEntityKeyPrefix()));
 
         // Expected 4 rows - one for GlobalView, one for TenantView and ViewIndex each.
-        // Since the VIEW_TTL property values are being set, we expect the view header columns to show up in regular scans too.
-        assertViewHeaderRowsHaveViewTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, false, 4);
-        assertSyscatHaveViewTTLRelatedColumns("", schemaName, globalViewName, PTableType.VIEW.getSerializedValue(), 300000);
-        assertSyscatHaveViewTTLRelatedColumns("", schemaName, indexOnGlobalViewName, PTableType.INDEX.getSerializedValue(), 300000);
-        // Since the VIEW_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 1000);
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 1000);
+        // Since the PHOENIX_TTL property values are being set, we expect the view header columns to show up in regular scans too.
+        assertViewHeaderRowsHavePhoenixTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, false, 4);
+        assertSyscatHavePhoenixTTLRelatedColumns("", schemaName, globalViewName, PTableType.VIEW.getSerializedValue(), 300000);
+        assertSyscatHavePhoenixTTLRelatedColumns("", schemaName, indexOnGlobalViewName, PTableType.INDEX.getSerializedValue(), 300000);
+        // Since the PHOENIX_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 1000);
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 1000);
 
         // Without override
         startTime = System.currentTimeMillis();
@@ -299,17 +299,17 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
 
 
         // Expected 2 rows - one for TenantView and ViewIndex each.
-        // Since the VIEW_TTL property values are being set, we expect the view header columns to show up in regular scans too.
-        assertViewHeaderRowsHaveViewTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, false, 2);
-        assertSyscatHaveViewTTLRelatedColumns("", schemaName, globalViewName, PTableType.VIEW.getSerializedValue(), 300000);
-        assertSyscatHaveViewTTLRelatedColumns("", schemaName, indexOnGlobalViewName, PTableType.INDEX.getSerializedValue(), 300000);
-        // Since the VIEW_TTL property values are not being overriden, we expect the TTL value to be same as the global view.
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 300000);
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 300000);
+        // Since the PHOENIX_TTL property values are being set, we expect the view header columns to show up in regular scans too.
+        assertViewHeaderRowsHavePhoenixTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, false, 2);
+        assertSyscatHavePhoenixTTLRelatedColumns("", schemaName, globalViewName, PTableType.VIEW.getSerializedValue(), 300000);
+        assertSyscatHavePhoenixTTLRelatedColumns("", schemaName, indexOnGlobalViewName, PTableType.INDEX.getSerializedValue(), 300000);
+        // Since the PHOENIX_TTL property values are not being overriden, we expect the TTL value to be same as the global view.
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 300000);
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 300000);
     }
 
     @Test
-    public void testViewTTLForWhenTTLIsZero() throws Exception {
+    public void testPhoenixTTLForWhenTTLIsZero() throws Exception {
         long startTime = System.currentTimeMillis();
 
         // Define the test schema.
@@ -321,8 +321,8 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         tableOptions.setTableProps("COLUMN_ENCODED_BYTES=0,MULTI_TENANT=true");
 
         TenantViewOptions tenantViewOptions = TenantViewOptions.withDefaults();
-        // Client can also specify VIEW_TTL=NONE
-        tenantViewOptions.setTableProps("VIEW_TTL=0");
+        // Client can also specify PHOENIX_TTL=NONE
+        tenantViewOptions.setTableProps("PHOENIX_TTL=0");
         schemaBuilder
                 .withTableOptions(tableOptions)
                 .withTenantViewOptions(tenantViewOptions)
@@ -335,17 +335,17 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         String indexOnTenantViewName = String.format("IDX_%s", stripQuotes(schemaBuilder.getEntityKeyPrefix()));
 
         // Expected 3 deleted rows - one for Table, one for TenantView and ViewIndex each.
-        // Since the VIEW_TTL property values are not being set or being set to zero,
+        // Since the PHOENIX_TTL property values are not being set or being set to zero,
         // we expect the view header columns to show up in raw scans only.
-        assertViewHeaderRowsHaveViewTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, true, 3);
-        // Since the VIEW_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 0);
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 0);
+        assertViewHeaderRowsHavePhoenixTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, true, 3);
+        // Since the PHOENIX_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 0);
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 0);
 
     }
 
     @Test
-    public void testViewTTLWithAlterView() throws Exception {
+    public void testPhoenixTTLWithAlterView() throws Exception {
         long startTime = System.currentTimeMillis();
 
         // Define the test schema.
@@ -357,8 +357,8 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         tableOptions.setTableProps("COLUMN_ENCODED_BYTES=0,MULTI_TENANT=true");
 
         TenantViewOptions tenantViewOptions = TenantViewOptions.withDefaults();
-        // Client can also specify VIEW_TTL=0
-        tenantViewOptions.setTableProps("VIEW_TTL=NONE");
+        // Client can also specify PHOENIX_TTL=0
+        tenantViewOptions.setTableProps("PHOENIX_TTL=NONE");
         schemaBuilder
                 .withTableOptions(tableOptions)
                 .withTenantViewOptions(tenantViewOptions)
@@ -371,26 +371,26 @@ public class ViewTTLIT extends ParallelStatsDisabledIT {
         String indexOnTenantViewName = String.format("IDX_%s", stripQuotes(schemaBuilder.getEntityKeyPrefix()));
 
         // Expected 3 deleted rows - one for Table, one for TenantView and ViewIndex each.
-        // Since the VIEW_TTL property values are not being set or being set to zero,
+        // Since the PHOENIX_TTL property values are not being set or being set to zero,
         // we expect the view header columns to show up in raw scans only.
-        assertViewHeaderRowsHaveViewTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, true, 3);
-        // Since the VIEW_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 0);
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 0);
+        assertViewHeaderRowsHavePhoenixTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, true, 3);
+        // Since the PHOENIX_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 0);
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 0);
 
         String tenantURL = getUrl() + ';' + TENANT_ID_ATTRIB + '=' + tenantId;
         try (Connection connection = DriverManager.getConnection(tenantURL)) {
             Statement stmt = connection.createStatement();
-            String sql = String.format(ALTER_VIEW_TTL_SQL, schemaName, tenantViewName, 1000);
+            String sql = String.format(ALTER_PHOENIX_TTL_SQL, schemaName, tenantViewName, 1000);
             stmt.execute(sql);
         }
 
         // Expected 2 rows - one for TenantView and ViewIndex each.
-        // Since the VIEW_TTL property values are being set, we expect the view header columns to show up in regular scans too.
-        assertViewHeaderRowsHaveViewTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, false, 2);
-        // Since the VIEW_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 1000);
-        assertSyscatHaveViewTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 1000);
+        // Since the PHOENIX_TTL property values are being set, we expect the view header columns to show up in regular scans too.
+        assertViewHeaderRowsHavePhoenixTTLRelatedCells(schemaBuilder.getTableOptions().getSchemaName(), startTime, false, 2);
+        // Since the PHOENIX_TTL property values are not being overriden, we expect the TTL value to be different from the global view.
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, tenantViewName, PTableType.VIEW.getSerializedValue(), 1000);
+        assertSyscatHavePhoenixTTLRelatedColumns(tenantId, schemaName, indexOnTenantViewName, PTableType.INDEX.getSerializedValue(), 1000);
 
     }
 
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/coprocessor/MetaDataEndpointImpl.java b/phoenix-core/src/main/java/org/apache/phoenix/coprocessor/MetaDataEndpointImpl.java
index cdd8400..b1435a7 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/coprocessor/MetaDataEndpointImpl.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/coprocessor/MetaDataEndpointImpl.java
@@ -48,7 +48,7 @@ import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.JAR_PATH_BYTES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.LINK_TYPE_BYTES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.MAX_VALUE_BYTES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.MIN_VALUE_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.MIN_VIEW_TTL_HWM;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.MIN_PHOENIX_TTL_HWM;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.MULTI_TENANT_BYTES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.NULLABLE_BYTES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.NUM_ARGS_BYTES;
@@ -72,9 +72,9 @@ import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_CONSTANT_BYTE
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_INDEX_ID_BYTES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_INDEX_ID_DATA_TYPE_BYTES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_STATEMENT_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TTL_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TTL_HWM_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TTL_NOT_DEFINED;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PHOENIX_TTL_BYTES;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PHOENIX_TTL_HWM_BYTES;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PHOENIX_TTL_NOT_DEFINED;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TYPE_BYTES;
 import static org.apache.phoenix.query.QueryConstants.VIEW_MODIFIED_PROPERTY_TAG_TYPE;
 import static org.apache.phoenix.schema.PTableType.INDEX;
@@ -328,8 +328,8 @@ public class MetaDataEndpointImpl extends MetaDataProtocol implements RegionCopr
     private static final Cell STORAGE_SCHEME_KV = createFirstOnRow(ByteUtil.EMPTY_BYTE_ARRAY, TABLE_FAMILY_BYTES, STORAGE_SCHEME_BYTES);
     private static final Cell ENCODING_SCHEME_KV = createFirstOnRow(ByteUtil.EMPTY_BYTE_ARRAY, TABLE_FAMILY_BYTES, ENCODING_SCHEME_BYTES);
     private static final Cell USE_STATS_FOR_PARALLELIZATION_KV = createFirstOnRow(ByteUtil.EMPTY_BYTE_ARRAY, TABLE_FAMILY_BYTES, USE_STATS_FOR_PARALLELIZATION_BYTES);
-    private static final KeyValue VIEW_TTL_KV = createFirstOnRow(ByteUtil.EMPTY_BYTE_ARRAY, TABLE_FAMILY_BYTES, VIEW_TTL_BYTES);
-    private static final KeyValue VIEW_TTL_HWM_KV = createFirstOnRow(ByteUtil.EMPTY_BYTE_ARRAY, TABLE_FAMILY_BYTES, VIEW_TTL_HWM_BYTES);
+    private static final KeyValue PHOENIX_TTL_KV = createFirstOnRow(ByteUtil.EMPTY_BYTE_ARRAY, TABLE_FAMILY_BYTES, PHOENIX_TTL_BYTES);
+    private static final KeyValue PHOENIX_TTL_HWM_KV = createFirstOnRow(ByteUtil.EMPTY_BYTE_ARRAY, TABLE_FAMILY_BYTES, PHOENIX_TTL_HWM_BYTES);
 
     private static final List<Cell> TABLE_KV_COLUMNS = Arrays.<Cell>asList(
             EMPTY_KEYVALUE_KV,
@@ -362,8 +362,8 @@ public class MetaDataEndpointImpl extends MetaDataProtocol implements RegionCopr
             STORAGE_SCHEME_KV,
             ENCODING_SCHEME_KV,
             USE_STATS_FOR_PARALLELIZATION_KV,
-            VIEW_TTL_KV,
-            VIEW_TTL_HWM_KV
+            PHOENIX_TTL_KV,
+            PHOENIX_TTL_HWM_KV
     );
 
     static {
@@ -399,8 +399,8 @@ public class MetaDataEndpointImpl extends MetaDataProtocol implements RegionCopr
     private static final int STORAGE_SCHEME_INDEX = TABLE_KV_COLUMNS.indexOf(STORAGE_SCHEME_KV);
     private static final int QUALIFIER_ENCODING_SCHEME_INDEX = TABLE_KV_COLUMNS.indexOf(ENCODING_SCHEME_KV);
     private static final int USE_STATS_FOR_PARALLELIZATION_INDEX = TABLE_KV_COLUMNS.indexOf(USE_STATS_FOR_PARALLELIZATION_KV);
-    private static final int VIEW_TTL_INDEX = TABLE_KV_COLUMNS.indexOf(VIEW_TTL_KV);
-    private static final int VIEW_TTL_HWM_INDEX = TABLE_KV_COLUMNS.indexOf(VIEW_TTL_HWM_KV);
+    private static final int PHOENIX_TTL_INDEX = TABLE_KV_COLUMNS.indexOf(PHOENIX_TTL_KV);
+    private static final int PHOENIX_TTL_HWM_INDEX = TABLE_KV_COLUMNS.indexOf(PHOENIX_TTL_HWM_KV);
 
     // KeyValues for Column
     private static final KeyValue DECIMAL_DIGITS_KV = createFirstOnRow(ByteUtil.EMPTY_BYTE_ARRAY, TABLE_FAMILY_BYTES, DECIMAL_DIGITS_BYTES);
@@ -1135,21 +1135,21 @@ public class MetaDataEndpointImpl extends MetaDataProtocol implements RegionCopr
                         encodingSchemeKv.getValueOffset(), encodingSchemeKv.getValueLength()));
         Cell useStatsForParallelizationKv = tableKeyValues[USE_STATS_FOR_PARALLELIZATION_INDEX];
         Boolean useStatsForParallelization = useStatsForParallelizationKv == null ? null : Boolean.TRUE.equals(PBoolean.INSTANCE.toObject(useStatsForParallelizationKv.getValueArray(), useStatsForParallelizationKv.getValueOffset(), useStatsForParallelizationKv.getValueLength()));
-        Cell viewTTLKv = tableKeyValues[VIEW_TTL_INDEX];
-        long viewTTL = viewTTLKv == null ? VIEW_TTL_NOT_DEFINED :
-                PLong.INSTANCE.getCodec().decodeLong(viewTTLKv.getValueArray(),
-                        viewTTLKv.getValueOffset(), SortOrder.getDefault());
+        Cell phoenixTTLKv = tableKeyValues[PHOENIX_TTL_INDEX];
+        long phoenixTTL = phoenixTTLKv == null ? PHOENIX_TTL_NOT_DEFINED :
+                PLong.INSTANCE.getCodec().decodeLong(phoenixTTLKv.getValueArray(),
+                        phoenixTTLKv.getValueOffset(), SortOrder.getDefault());
 
-        Cell viewTTLHWMKv = tableKeyValues[VIEW_TTL_HWM_INDEX];
-        long viewTTLHWM = viewTTLHWMKv == null ? MIN_VIEW_TTL_HWM :
-                PLong.INSTANCE.getCodec().decodeLong(viewTTLHWMKv.getValueArray(),
-                        viewTTLHWMKv.getValueOffset(), SortOrder.getDefault());
+        Cell phoenixTTLHWMKv = tableKeyValues[PHOENIX_TTL_HWM_INDEX];
+        long phoenixTTLHWM = phoenixTTLHWMKv == null ? MIN_PHOENIX_TTL_HWM :
+                PLong.INSTANCE.getCodec().decodeLong(phoenixTTLHWMKv.getValueArray(),
+                        phoenixTTLHWMKv.getValueOffset(), SortOrder.getDefault());
 
         // Check the cell tag to see whether the view has modified this property
-        final byte[] tagViewTTL = (viewTTLKv == null) ?
-                HConstants.EMPTY_BYTE_ARRAY : CellUtil.getTagArray(viewTTLKv);
-        boolean viewModifiedViewTTL = (PTableType.VIEW.equals(tableType)) &&
-                Bytes.contains(tagViewTTL, VIEW_MODIFIED_PROPERTY_BYTES);
+        final byte[] tagPhoenixTTL = (phoenixTTLKv == null) ?
+                HConstants.EMPTY_BYTE_ARRAY : CellUtil.getTagArray(phoenixTTLKv);
+        boolean viewModifiedPhoenixTTL = (PTableType.VIEW.equals(tableType)) &&
+                Bytes.contains(tagPhoenixTTL, VIEW_MODIFIED_PROPERTY_BYTES);
 
         // Check the cell tag to see whether the view has modified this property
         byte[] tagUseStatsForParallelization = (useStatsForParallelizationKv == null) ?
@@ -1227,8 +1227,8 @@ public class MetaDataEndpointImpl extends MetaDataProtocol implements RegionCopr
                 .setBaseColumnCount(baseColumnCount)
                 .setEncodedCQCounter(cqCounter)
                 .setUseStatsForParallelization(useStatsForParallelization)
-                .setViewTTL(viewTTL)
-                .setViewTTLHighWaterMark(viewTTLHWM)
+                .setPhoenixTTL(phoenixTTL)
+                .setPhoenixTTLHighWaterMark(phoenixTTLHWM)
                 .setExcludedColumns(ImmutableList.of())
                 .setTenantId(tenantId)
                 .setSchemaName(schemaName)
@@ -1244,7 +1244,7 @@ public class MetaDataEndpointImpl extends MetaDataProtocol implements RegionCopr
                         ImmutableList.of() : ImmutableList.copyOf(physicalTables))
                 .setViewModifiedUpdateCacheFrequency(viewModifiedUpdateCacheFrequency)
                 .setViewModifiedUseStatsForParallelization(viewModifiedUseStatsForParallelization)
-                .setViewModifiedViewTTL(viewModifiedViewTTL)
+                .setViewModifiedPhoenixTTL(viewModifiedPhoenixTTL)
                 .setColumns(columns)
                 .build();
     }
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/coprocessor/generated/PTableProtos.java b/phoenix-core/src/main/java/org/apache/phoenix/coprocessor/generated/PTableProtos.java
index 2d14171..9a935e9 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/coprocessor/generated/PTableProtos.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/coprocessor/generated/PTableProtos.java
@@ -3725,35 +3725,35 @@ public final class PTableProtos {
      */
     boolean getViewModifiedUseStatsForParallelization();
 
-    // optional int64 viewTTL = 42;
+    // optional int64 phoenixTTL = 42;
     /**
-     * <code>optional int64 viewTTL = 42;</code>
+     * <code>optional int64 phoenixTTL = 42;</code>
      */
-    boolean hasViewTTL();
+    boolean hasPhoenixTTL();
     /**
-     * <code>optional int64 viewTTL = 42;</code>
+     * <code>optional int64 phoenixTTL = 42;</code>
      */
-    long getViewTTL();
+    long getPhoenixTTL();
 
-    // optional int64 viewTTLHighWaterMark = 43;
+    // optional int64 phoenixTTLHighWaterMark = 43;
     /**
-     * <code>optional int64 viewTTLHighWaterMark = 43;</code>
+     * <code>optional int64 phoenixTTLHighWaterMark = 43;</code>
      */
-    boolean hasViewTTLHighWaterMark();
+    boolean hasPhoenixTTLHighWaterMark();
     /**
-     * <code>optional int64 viewTTLHighWaterMark = 43;</code>
+     * <code>optional int64 phoenixTTLHighWaterMark = 43;</code>
      */
-    long getViewTTLHighWaterMark();
+    long getPhoenixTTLHighWaterMark();
 
-    // optional bool viewModifiedViewTTL = 44;
+    // optional bool viewModifiedPhoenixTTL = 44;
     /**
-     * <code>optional bool viewModifiedViewTTL = 44;</code>
+     * <code>optional bool viewModifiedPhoenixTTL = 44;</code>
      */
-    boolean hasViewModifiedViewTTL();
+    boolean hasViewModifiedPhoenixTTL();
     /**
-     * <code>optional bool viewModifiedViewTTL = 44;</code>
+     * <code>optional bool viewModifiedPhoenixTTL = 44;</code>
      */
-    boolean getViewModifiedViewTTL();
+    boolean getViewModifiedPhoenixTTL();
   }
   /**
    * Protobuf type {@code PTable}
@@ -4027,17 +4027,17 @@ public final class PTableProtos {
             }
             case 336: {
               bitField1_ |= 0x00000010;
-              viewTTL_ = input.readInt64();
+              phoenixTTL_ = input.readInt64();
               break;
             }
             case 344: {
               bitField1_ |= 0x00000020;
-              viewTTLHighWaterMark_ = input.readInt64();
+              phoenixTTLHighWaterMark_ = input.readInt64();
               break;
             }
             case 352: {
               bitField1_ |= 0x00000040;
-              viewModifiedViewTTL_ = input.readBool();
+              viewModifiedPhoenixTTL_ = input.readBool();
               break;
             }
           }
@@ -4868,52 +4868,52 @@ public final class PTableProtos {
       return viewModifiedUseStatsForParallelization_;
     }
 
-    // optional int64 viewTTL = 42;
-    public static final int VIEWTTL_FIELD_NUMBER = 42;
-    private long viewTTL_;
+    // optional int64 phoenixTTL = 42;
+    public static final int PHOENIXTTL_FIELD_NUMBER = 42;
+    private long phoenixTTL_;
     /**
-     * <code>optional int64 viewTTL = 42;</code>
+     * <code>optional int64 phoenixTTL = 42;</code>
      */
-    public boolean hasViewTTL() {
+    public boolean hasPhoenixTTL() {
       return ((bitField1_ & 0x00000010) == 0x00000010);
     }
     /**
-     * <code>optional int64 viewTTL = 42;</code>
+     * <code>optional int64 phoenixTTL = 42;</code>
      */
-    public long getViewTTL() {
-      return viewTTL_;
+    public long getPhoenixTTL() {
+      return phoenixTTL_;
     }
 
-    // optional int64 viewTTLHighWaterMark = 43;
-    public static final int VIEWTTLHIGHWATERMARK_FIELD_NUMBER = 43;
-    private long viewTTLHighWaterMark_;
+    // optional int64 phoenixTTLHighWaterMark = 43;
+    public static final int PHOENIXTTLHIGHWATERMARK_FIELD_NUMBER = 43;
+    private long phoenixTTLHighWaterMark_;
     /**
-     * <code>optional int64 viewTTLHighWaterMark = 43;</code>
+     * <code>optional int64 phoenixTTLHighWaterMark = 43;</code>
      */
-    public boolean hasViewTTLHighWaterMark() {
+    public boolean hasPhoenixTTLHighWaterMark() {
       return ((bitField1_ & 0x00000020) == 0x00000020);
     }
     /**
-     * <code>optional int64 viewTTLHighWaterMark = 43;</code>
+     * <code>optional int64 phoenixTTLHighWaterMark = 43;</code>
      */
-    public long getViewTTLHighWaterMark() {
-      return viewTTLHighWaterMark_;
+    public long getPhoenixTTLHighWaterMark() {
+      return phoenixTTLHighWaterMark_;
     }
 
-    // optional bool viewModifiedViewTTL = 44;
-    public static final int VIEWMODIFIEDVIEWTTL_FIELD_NUMBER = 44;
-    private boolean viewModifiedViewTTL_;
+    // optional bool viewModifiedPhoenixTTL = 44;
+    public static final int VIEWMODIFIEDPHOENIXTTL_FIELD_NUMBER = 44;
+    private boolean viewModifiedPhoenixTTL_;
     /**
-     * <code>optional bool viewModifiedViewTTL = 44;</code>
+     * <code>optional bool viewModifiedPhoenixTTL = 44;</code>
      */
-    public boolean hasViewModifiedViewTTL() {
+    public boolean hasViewModifiedPhoenixTTL() {
       return ((bitField1_ & 0x00000040) == 0x00000040);
     }
     /**
-     * <code>optional bool viewModifiedViewTTL = 44;</code>
+     * <code>optional bool viewModifiedPhoenixTTL = 44;</code>
      */
-    public boolean getViewModifiedViewTTL() {
-      return viewModifiedViewTTL_;
+    public boolean getViewModifiedPhoenixTTL() {
+      return viewModifiedPhoenixTTL_;
     }
 
     private void initFields() {
@@ -4957,9 +4957,9 @@ public final class PTableProtos {
       viewIndexIdType_ = 5;
       viewModifiedUpdateCacheFrequency_ = false;
       viewModifiedUseStatsForParallelization_ = false;
-      viewTTL_ = 0L;
-      viewTTLHighWaterMark_ = 0L;
-      viewModifiedViewTTL_ = false;
+      phoenixTTL_ = 0L;
+      phoenixTTLHighWaterMark_ = 0L;
+      viewModifiedPhoenixTTL_ = false;
     }
     private byte memoizedIsInitialized = -1;
     public final boolean isInitialized() {
@@ -5148,13 +5148,13 @@ public final class PTableProtos {
         output.writeBool(41, viewModifiedUseStatsForParallelization_);
       }
       if (((bitField1_ & 0x00000010) == 0x00000010)) {
-        output.writeInt64(42, viewTTL_);
+        output.writeInt64(42, phoenixTTL_);
       }
       if (((bitField1_ & 0x00000020) == 0x00000020)) {
-        output.writeInt64(43, viewTTLHighWaterMark_);
+        output.writeInt64(43, phoenixTTLHighWaterMark_);
       }
       if (((bitField1_ & 0x00000040) == 0x00000040)) {
-        output.writeBool(44, viewModifiedViewTTL_);
+        output.writeBool(44, viewModifiedPhoenixTTL_);
       }
       getUnknownFields().writeTo(output);
     }
@@ -5332,15 +5332,15 @@ public final class PTableProtos {
       }
       if (((bitField1_ & 0x00000010) == 0x00000010)) {
         size += com.google.protobuf.CodedOutputStream
-          .computeInt64Size(42, viewTTL_);
+          .computeInt64Size(42, phoenixTTL_);
       }
       if (((bitField1_ & 0x00000020) == 0x00000020)) {
         size += com.google.protobuf.CodedOutputStream
-          .computeInt64Size(43, viewTTLHighWaterMark_);
+          .computeInt64Size(43, phoenixTTLHighWaterMark_);
       }
       if (((bitField1_ & 0x00000040) == 0x00000040)) {
         size += com.google.protobuf.CodedOutputStream
-          .computeBoolSize(44, viewModifiedViewTTL_);
+          .computeBoolSize(44, viewModifiedPhoenixTTL_);
       }
       size += getUnknownFields().getSerializedSize();
       memoizedSerializedSize = size;
@@ -5553,20 +5553,20 @@ public final class PTableProtos {
         result = result && (getViewModifiedUseStatsForParallelization()
             == other.getViewModifiedUseStatsForParallelization());
       }
-      result = result && (hasViewTTL() == other.hasViewTTL());
-      if (hasViewTTL()) {
-        result = result && (getViewTTL()
-            == other.getViewTTL());
+      result = result && (hasPhoenixTTL() == other.hasPhoenixTTL());
+      if (hasPhoenixTTL()) {
+        result = result && (getPhoenixTTL()
+            == other.getPhoenixTTL());
       }
-      result = result && (hasViewTTLHighWaterMark() == other.hasViewTTLHighWaterMark());
-      if (hasViewTTLHighWaterMark()) {
-        result = result && (getViewTTLHighWaterMark()
-            == other.getViewTTLHighWaterMark());
+      result = result && (hasPhoenixTTLHighWaterMark() == other.hasPhoenixTTLHighWaterMark());
+      if (hasPhoenixTTLHighWaterMark()) {
+        result = result && (getPhoenixTTLHighWaterMark()
+            == other.getPhoenixTTLHighWaterMark());
       }
-      result = result && (hasViewModifiedViewTTL() == other.hasViewModifiedViewTTL());
-      if (hasViewModifiedViewTTL()) {
-        result = result && (getViewModifiedViewTTL()
-            == other.getViewModifiedViewTTL());
+      result = result && (hasViewModifiedPhoenixTTL() == other.hasViewModifiedPhoenixTTL());
+      if (hasViewModifiedPhoenixTTL()) {
+        result = result && (getViewModifiedPhoenixTTL()
+            == other.getViewModifiedPhoenixTTL());
       }
       result = result &&
           getUnknownFields().equals(other.getUnknownFields());
@@ -5741,17 +5741,17 @@ public final class PTableProtos {
         hash = (37 * hash) + VIEWMODIFIEDUSESTATSFORPARALLELIZATION_FIELD_NUMBER;
         hash = (53 * hash) + hashBoolean(getViewModifiedUseStatsForParallelization());
       }
-      if (hasViewTTL()) {
-        hash = (37 * hash) + VIEWTTL_FIELD_NUMBER;
-        hash = (53 * hash) + hashLong(getViewTTL());
+      if (hasPhoenixTTL()) {
+        hash = (37 * hash) + PHOENIXTTL_FIELD_NUMBER;
+        hash = (53 * hash) + hashLong(getPhoenixTTL());
       }
-      if (hasViewTTLHighWaterMark()) {
-        hash = (37 * hash) + VIEWTTLHIGHWATERMARK_FIELD_NUMBER;
-        hash = (53 * hash) + hashLong(getViewTTLHighWaterMark());
+      if (hasPhoenixTTLHighWaterMark()) {
+        hash = (37 * hash) + PHOENIXTTLHIGHWATERMARK_FIELD_NUMBER;
+        hash = (53 * hash) + hashLong(getPhoenixTTLHighWaterMark());
       }
-      if (hasViewModifiedViewTTL()) {
-        hash = (37 * hash) + VIEWMODIFIEDVIEWTTL_FIELD_NUMBER;
-        hash = (53 * hash) + hashBoolean(getViewModifiedViewTTL());
+      if (hasViewModifiedPhoenixTTL()) {
+        hash = (37 * hash) + VIEWMODIFIEDPHOENIXTTL_FIELD_NUMBER;
+        hash = (53 * hash) + hashBoolean(getViewModifiedPhoenixTTL());
       }
       hash = (29 * hash) + getUnknownFields().hashCode();
       memoizedHashCode = hash;
@@ -5957,11 +5957,11 @@ public final class PTableProtos {
         bitField1_ = (bitField1_ & ~0x00000040);
         viewModifiedUseStatsForParallelization_ = false;
         bitField1_ = (bitField1_ & ~0x00000080);
-        viewTTL_ = 0L;
+        phoenixTTL_ = 0L;
         bitField1_ = (bitField1_ & ~0x00000100);
-        viewTTLHighWaterMark_ = 0L;
+        phoenixTTLHighWaterMark_ = 0L;
         bitField1_ = (bitField1_ & ~0x00000200);
-        viewModifiedViewTTL_ = false;
+        viewModifiedPhoenixTTL_ = false;
         bitField1_ = (bitField1_ & ~0x00000400);
         return this;
       }
@@ -6172,15 +6172,15 @@ public final class PTableProtos {
         if (((from_bitField1_ & 0x00000100) == 0x00000100)) {
           to_bitField1_ |= 0x00000010;
         }
-        result.viewTTL_ = viewTTL_;
+        result.phoenixTTL_ = phoenixTTL_;
         if (((from_bitField1_ & 0x00000200) == 0x00000200)) {
           to_bitField1_ |= 0x00000020;
         }
-        result.viewTTLHighWaterMark_ = viewTTLHighWaterMark_;
+        result.phoenixTTLHighWaterMark_ = phoenixTTLHighWaterMark_;
         if (((from_bitField1_ & 0x00000400) == 0x00000400)) {
           to_bitField1_ |= 0x00000040;
         }
-        result.viewModifiedViewTTL_ = viewModifiedViewTTL_;
+        result.viewModifiedPhoenixTTL_ = viewModifiedPhoenixTTL_;
         result.bitField0_ = to_bitField0_;
         result.bitField1_ = to_bitField1_;
         onBuilt();
@@ -6398,14 +6398,14 @@ public final class PTableProtos {
         if (other.hasViewModifiedUseStatsForParallelization()) {
           setViewModifiedUseStatsForParallelization(other.getViewModifiedUseStatsForParallelization());
         }
-        if (other.hasViewTTL()) {
-          setViewTTL(other.getViewTTL());
+        if (other.hasPhoenixTTL()) {
+          setPhoenixTTL(other.getPhoenixTTL());
         }
-        if (other.hasViewTTLHighWaterMark()) {
-          setViewTTLHighWaterMark(other.getViewTTLHighWaterMark());
+        if (other.hasPhoenixTTLHighWaterMark()) {
+          setPhoenixTTLHighWaterMark(other.getPhoenixTTLHighWaterMark());
         }
-        if (other.hasViewModifiedViewTTL()) {
-          setViewModifiedViewTTL(other.getViewModifiedViewTTL());
+        if (other.hasViewModifiedPhoenixTTL()) {
+          setViewModifiedPhoenixTTL(other.getViewModifiedPhoenixTTL());
         }
         this.mergeUnknownFields(other.getUnknownFields());
         return this;
@@ -8618,101 +8618,101 @@ public final class PTableProtos {
         return this;
       }
 
-      // optional int64 viewTTL = 42;
-      private long viewTTL_ ;
+      // optional int64 phoenixTTL = 42;
+      private long phoenixTTL_ ;
       /**
-       * <code>optional int64 viewTTL = 42;</code>
+       * <code>optional int64 phoenixTTL = 42;</code>
        */
-      public boolean hasViewTTL() {
+      public boolean hasPhoenixTTL() {
         return ((bitField1_ & 0x00000100) == 0x00000100);
       }
       /**
-       * <code>optional int64 viewTTL = 42;</code>
+       * <code>optional int64 phoenixTTL = 42;</code>
        */
-      public long getViewTTL() {
-        return viewTTL_;
+      public long getPhoenixTTL() {
+        return phoenixTTL_;
       }
       /**
-       * <code>optional int64 viewTTL = 42;</code>
+       * <code>optional int64 phoenixTTL = 42;</code>
        */
-      public Builder setViewTTL(long value) {
+      public Builder setPhoenixTTL(long value) {
         bitField1_ |= 0x00000100;
-        viewTTL_ = value;
+        phoenixTTL_ = value;
         onChanged();
         return this;
       }
       /**
-       * <code>optional int64 viewTTL = 42;</code>
+       * <code>optional int64 phoenixTTL = 42;</code>
        */
-      public Builder clearViewTTL() {
+      public Builder clearPhoenixTTL() {
         bitField1_ = (bitField1_ & ~0x00000100);
-        viewTTL_ = 0L;
+        phoenixTTL_ = 0L;
         onChanged();
         return this;
       }
 
-      // optional int64 viewTTLHighWaterMark = 43;
-      private long viewTTLHighWaterMark_ ;
+      // optional int64 phoenixTTLHighWaterMark = 43;
+      private long phoenixTTLHighWaterMark_ ;
       /**
-       * <code>optional int64 viewTTLHighWaterMark = 43;</code>
+       * <code>optional int64 phoenixTTLHighWaterMark = 43;</code>
        */
-      public boolean hasViewTTLHighWaterMark() {
+      public boolean hasPhoenixTTLHighWaterMark() {
         return ((bitField1_ & 0x00000200) == 0x00000200);
       }
       /**
-       * <code>optional int64 viewTTLHighWaterMark = 43;</code>
+       * <code>optional int64 phoenixTTLHighWaterMark = 43;</code>
        */
-      public long getViewTTLHighWaterMark() {
-        return viewTTLHighWaterMark_;
+      public long getPhoenixTTLHighWaterMark() {
+        return phoenixTTLHighWaterMark_;
       }
       /**
-       * <code>optional int64 viewTTLHighWaterMark = 43;</code>
+       * <code>optional int64 phoenixTTLHighWaterMark = 43;</code>
        */
-      public Builder setViewTTLHighWaterMark(long value) {
+      public Builder setPhoenixTTLHighWaterMark(long value) {
         bitField1_ |= 0x00000200;
-        viewTTLHighWaterMark_ = value;
+        phoenixTTLHighWaterMark_ = value;
         onChanged();
         return this;
       }
       /**
-       * <code>optional int64 viewTTLHighWaterMark = 43;</code>
+       * <code>optional int64 phoenixTTLHighWaterMark = 43;</code>
        */
-      public Builder clearViewTTLHighWaterMark() {
+      public Builder clearPhoenixTTLHighWaterMark() {
         bitField1_ = (bitField1_ & ~0x00000200);
-        viewTTLHighWaterMark_ = 0L;
+        phoenixTTLHighWaterMark_ = 0L;
         onChanged();
         return this;
       }
 
-      // optional bool viewModifiedViewTTL = 44;
-      private boolean viewModifiedViewTTL_ ;
+      // optional bool viewModifiedPhoenixTTL = 44;
+      private boolean viewModifiedPhoenixTTL_ ;
       /**
-       * <code>optional bool viewModifiedViewTTL = 44;</code>
+       * <code>optional bool viewModifiedPhoenixTTL = 44;</code>
        */
-      public boolean hasViewModifiedViewTTL() {
+      public boolean hasViewModifiedPhoenixTTL() {
         return ((bitField1_ & 0x00000400) == 0x00000400);
       }
       /**
-       * <code>optional bool viewModifiedViewTTL = 44;</code>
+       * <code>optional bool viewModifiedPhoenixTTL = 44;</code>
        */
-      public boolean getViewModifiedViewTTL() {
-        return viewModifiedViewTTL_;
+      public boolean getViewModifiedPhoenixTTL() {
+        return viewModifiedPhoenixTTL_;
       }
       /**
-       * <code>optional bool viewModifiedViewTTL = 44;</code>
+       * <code>optional bool viewModifiedPhoenixTTL = 44;</code>
        */
-      public Builder setViewModifiedViewTTL(boolean value) {
+      public Builder setViewModifiedPhoenixTTL(boolean value) {
         bitField1_ |= 0x00000400;
-        viewModifiedViewTTL_ = value;
+        viewModifiedPhoenixTTL_ = value;
         onChanged();
         return this;
       }
       /**
-       * <code>optional bool viewModifiedViewTTL = 44;</code>
+       * <code>optional bool viewModifiedPhoenixTTL = 44;</code>
        */
-      public Builder clearViewModifiedViewTTL() {
+      public Builder clearViewModifiedPhoenixTTL() {
         bitField1_ = (bitField1_ & ~0x00000400);
-        viewModifiedViewTTL_ = false;
+        viewModifiedPhoenixTTL_ = false;
         onChanged();
         return this;
       }
@@ -9386,7 +9386,7 @@ public final class PTableProtos {
       "es\030\002 \003(\014\022\033\n\023guidePostsByteCount\030\003 \001(\003\022\025\n" +
       "\rkeyBytesCount\030\004 \001(\003\022\027\n\017guidePostsCount\030" +
       "\005 \001(\005\022!\n\013pGuidePosts\030\006 \001(\0132\014.PGuidePosts" +
-      "\"\357\010\n\006PTable\022\027\n\017schemaNameBytes\030\001 \002(\014\022\026\n\016" +
+      "\"\370\010\n\006PTable\022\027\n\017schemaNameBytes\030\001 \002(\014\022\026\n\016" +
       "tableNameBytes\030\002 \002(\014\022\036\n\ttableType\030\003 \002(\0162" +
       "\013.PTableType\022\022\n\nindexState\030\004 \001(\t\022\026\n\016sequ" +
       "enceNumber\030\005 \002(\003\022\021\n\ttimeStamp\030\006 \002(\003\022\023\n\013p" +
@@ -9412,14 +9412,14 @@ public final class PTableProtos {
       "ransactionProvider\030& \001(\005\022\032\n\017viewIndexIdT" +
       "ype\030\' \001(\005:\0015\022(\n viewModifiedUpdateCacheF" +
       "requency\030( \001(\010\022.\n&viewModifiedUseStatsFo",
-      "rParallelization\030) \001(\010\022\017\n\007viewTTL\030* \001(\003\022" +
-      "\034\n\024viewTTLHighWaterMark\030+ \001(\003\022\033\n\023viewMod" +
-      "ifiedViewTTL\030, \001(\010\"6\n\020EncodedCQCounter\022\021" +
-      "\n\tcolFamily\030\001 \002(\t\022\017\n\007counter\030\002 \002(\005*A\n\nPT" +
-      "ableType\022\n\n\006SYSTEM\020\000\022\010\n\004USER\020\001\022\010\n\004VIEW\020\002" +
-      "\022\t\n\005INDEX\020\003\022\010\n\004JOIN\020\004B@\n(org.apache.phoe" +
-      "nix.coprocessor.generatedB\014PTableProtosH" +
-      "\001\210\001\001\240\001\001"
+      "rParallelization\030) \001(\010\022\022\n\nphoenixTTL\030* \001" +
+      "(\003\022\037\n\027phoenixTTLHighWaterMark\030+ \001(\003\022\036\n\026v" +
+      "iewModifiedPhoenixTTL\030, \001(\010\"6\n\020EncodedCQ" +
+      "Counter\022\021\n\tcolFamily\030\001 \002(\t\022\017\n\007counter\030\002 " +
+      "\002(\005*A\n\nPTableType\022\n\n\006SYSTEM\020\000\022\010\n\004USER\020\001\022" +
+      "\010\n\004VIEW\020\002\022\t\n\005INDEX\020\003\022\010\n\004JOIN\020\004B@\n(org.ap" +
+      "ache.phoenix.coprocessor.generatedB\014PTab" +
+      "leProtosH\001\210\001\001\240\001\001"
     };
     com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
       new com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner() {
@@ -9443,7 +9443,7 @@ public final class PTableProtos {
           internal_static_PTable_fieldAccessorTable = new
             com.google.protobuf.GeneratedMessage.FieldAccessorTable(
               internal_static_PTable_descriptor,
-              new java.lang.String[] { "SchemaNameBytes", "TableNameBytes", "TableType", "IndexState", "SequenceNumber", "TimeStamp", "PkNameBytes", "BucketNum", "Columns", "Indexes", "IsImmutableRows", "DataTableNameBytes", "DefaultFamilyName", "DisableWAL", "MultiTenant", "ViewType", "ViewStatement", "PhysicalNames", "TenantId", "ViewIndexId", "IndexType", "StatsTimeStamp", "StoreNulls", "BaseColumnCount", "RowKeyOrderOptimizable", "Transactional", "UpdateCacheFrequency", "IndexDisable [...]
+              new java.lang.String[] { "SchemaNameBytes", "TableNameBytes", "TableType", "IndexState", "SequenceNumber", "TimeStamp", "PkNameBytes", "BucketNum", "Columns", "Indexes", "IsImmutableRows", "DataTableNameBytes", "DefaultFamilyName", "DisableWAL", "MultiTenant", "ViewType", "ViewStatement", "PhysicalNames", "TenantId", "ViewIndexId", "IndexType", "StatsTimeStamp", "StoreNulls", "BaseColumnCount", "RowKeyOrderOptimizable", "Transactional", "UpdateCacheFrequency", "IndexDisable [...]
           internal_static_EncodedCQCounter_descriptor =
             getDescriptor().getMessageTypes().get(3);
           internal_static_EncodedCQCounter_fieldAccessorTable = new
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/exception/SQLExceptionCode.java b/phoenix-core/src/main/java/org/apache/phoenix/exception/SQLExceptionCode.java
index 2f271c5..8c83c6f 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/exception/SQLExceptionCode.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/exception/SQLExceptionCode.java
@@ -323,10 +323,10 @@ public enum SQLExceptionCode {
             + MetaDataUtil.SYNCED_DATA_TABLE_AND_INDEX_COL_FAM_PROPERTIES.toString()),
     CANNOT_SET_OR_ALTER_UPDATE_CACHE_FREQ_FOR_INDEX(10950, "44A31", "Cannot set or alter "
             + PhoenixDatabaseMetaData.UPDATE_CACHE_FREQUENCY + " on an index"),
-    VIEW_TTL_SUPPORTED_FOR_VIEWS_ONLY(10951, "44A32", PhoenixDatabaseMetaData.VIEW_TTL
+    PHOENIX_TTL_SUPPORTED_FOR_VIEWS_ONLY(10951, "44A32", PhoenixDatabaseMetaData.PHOENIX_TTL
             + " property can only be set for views"),
-    CANNOT_SET_OR_ALTER_VIEW_TTL_FOR_TABLE_WITH_TTL(10952, "44A33", "Cannot set or alter "
-            + PhoenixDatabaseMetaData.VIEW_TTL + " property on an table with TTL,"),
+    CANNOT_SET_OR_ALTER_PHOENIX_TTL_FOR_TABLE_WITH_TTL(10952, "44A33", "Cannot set or alter "
+            + PhoenixDatabaseMetaData.PHOENIX_TTL + " property on an table with TTL,"),
     ABOVE_INDEX_NON_ASYNC_THRESHOLD(1097, "44A34", "The estimated read size for index creation "
             + "is higher than " + QueryServices.CLIENT_INDEX_ASYNC_THRESHOLD+ ". You can edit the"
             + " limit or create ASYNC index."),
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/query/ConnectionQueryServicesImpl.java b/phoenix-core/src/main/java/org/apache/phoenix/query/ConnectionQueryServicesImpl.java
index d5b0720..f8e6d0a 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/query/ConnectionQueryServicesImpl.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/query/ConnectionQueryServicesImpl.java
@@ -3650,13 +3650,13 @@ public class ConnectionQueryServicesImpl extends DelegateQueryServices implement
                     metaConnection,
                     PhoenixDatabaseMetaData.SYSTEM_CATALOG,
                     MIN_SYSTEM_TABLE_TIMESTAMP_4_16_0 - 1,
-                    PhoenixDatabaseMetaData.VIEW_TTL + " "
+                    PhoenixDatabaseMetaData.PHOENIX_TTL + " "
                             + PInteger.INSTANCE.getSqlTypeName());
             metaConnection = addColumnsIfNotExists(
                     metaConnection,
                     PhoenixDatabaseMetaData.SYSTEM_CATALOG,
                     MIN_SYSTEM_TABLE_TIMESTAMP_4_16_0,
-                    PhoenixDatabaseMetaData.VIEW_TTL_HWM + " "
+                    PhoenixDatabaseMetaData.PHOENIX_TTL_HWM + " "
                             + PInteger.INSTANCE.getSqlTypeName());
         }
         return metaConnection;
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/query/QueryConstants.java b/phoenix-core/src/main/java/org/apache/phoenix/query/QueryConstants.java
index ae3488b..3cbe924 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/query/QueryConstants.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/query/QueryConstants.java
@@ -199,8 +199,8 @@ public interface QueryConstants {
             VIEW_TYPE + " UNSIGNED_TINYINT,\n" +
             VIEW_INDEX_ID + " BIGINT,\n" +
             VIEW_INDEX_ID_DATA_TYPE + " INTEGER,\n" +
-            VIEW_TTL + " BIGINT,\n" +
-            VIEW_TTL_HWM + " BIGINT,\n" +
+            PHOENIX_TTL + " BIGINT,\n" +
+            PHOENIX_TTL_HWM + " BIGINT,\n" +
             // Column metadata (will be null for table row)
             DATA_TYPE + " INTEGER," +
             COLUMN_SIZE + " INTEGER," +
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/schema/DelegateTable.java b/phoenix-core/src/main/java/org/apache/phoenix/schema/DelegateTable.java
index 3ce19dc..a2e9757 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/schema/DelegateTable.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/schema/DelegateTable.java
@@ -341,13 +341,13 @@ public class DelegateTable implements PTable {
         return delegate.hasViewModifiedUseStatsForParallelization();
     }
 
-    @Override public long getViewTTL() { return delegate.getViewTTL(); }
+    @Override public long getPhoenixTTL() { return delegate.getPhoenixTTL(); }
 
-    @Override public long getViewTTLHighWaterMark() {
-        return delegate.getViewTTLHighWaterMark();
+    @Override public long getPhoenixTTLHighWaterMark() {
+        return delegate.getPhoenixTTLHighWaterMark();
     }
 
-    @Override public boolean hasViewModifiedViewTTL() {
-        return delegate.hasViewModifiedViewTTL();
+    @Override public boolean hasViewModifiedPhoenixTTL() {
+        return delegate.hasViewModifiedPhoenixTTL();
     }
 }
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/schema/MetaDataClient.java b/phoenix-core/src/main/java/org/apache/phoenix/schema/MetaDataClient.java
index ad36544..02291ae 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/schema/MetaDataClient.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/schema/MetaDataClient.java
@@ -93,10 +93,10 @@ import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_CONSTANT;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_STATEMENT;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TYPE;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_INDEX_ID_DATA_TYPE;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TTL;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TTL_HWM;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TTL_NOT_DEFINED;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.MIN_VIEW_TTL_HWM;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PHOENIX_TTL;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PHOENIX_TTL_HWM;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PHOENIX_TTL_NOT_DEFINED;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.MIN_PHOENIX_TTL_HWM;
 import static org.apache.phoenix.query.QueryConstants.BASE_TABLE_BASE_COLUMN_COUNT;
 import static org.apache.phoenix.query.QueryConstants.DEFAULT_COLUMN_FAMILY;
 import static org.apache.phoenix.query.QueryConstants.ENCODED_CQ_COUNTER_INITIAL_VALUE;
@@ -319,8 +319,8 @@ public class MetaDataClient {
                     ENCODING_SCHEME + "," +
                     USE_STATS_FOR_PARALLELIZATION +"," +
                     VIEW_INDEX_ID_DATA_TYPE +"," +
-                    VIEW_TTL +"," +
-                    VIEW_TTL_HWM +
+                    PHOENIX_TTL +"," +
+                    PHOENIX_TTL_HWM +
                     ") VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
 
     private static final String CREATE_SCHEMA = "UPSERT INTO " + SYSTEM_CATALOG_SCHEMA + ".\"" + SYSTEM_CATALOG_TABLE
@@ -2052,14 +2052,14 @@ public class MetaDataClient {
                     tableType == PTableType.VIEW ? parent.getColumns().size()
                             : QueryConstants.BASE_TABLE_BASE_COLUMN_COUNT;
 
-            Long viewTTL = VIEW_TTL_NOT_DEFINED;
-            Long viewTTLHighWaterMark = MIN_VIEW_TTL_HWM;
-            Long viewTTLProp = (Long) TableProperty.VIEW_TTL.getValue(tableProps);;
+            Long phoenixTTL = PHOENIX_TTL_NOT_DEFINED;
+            Long phoenixTTLHighWaterMark = MIN_PHOENIX_TTL_HWM;
+            Long phoenixTTLProp = (Long) TableProperty.PHOENIX_TTL.getValue(tableProps);;
             // Validate VIEW_TTL prop value if set
-            if (viewTTLProp != null) {
-                if (viewTTLProp < 0) {
+            if (phoenixTTLProp != null) {
+                if (phoenixTTLProp < 0) {
                     throw new SQLExceptionInfo.Builder(SQLExceptionCode.ILLEGAL_DATA)
-                            .setMessage(String.format("view = %s, VIEW_TTL value should be > 0", tableName ))
+                            .setMessage(String.format("view = %s, PHOENIX_TTL value should be > 0", tableName ))
                             .build()
                             .buildException();
                 }
@@ -2069,7 +2069,7 @@ public class MetaDataClient {
                     if (desc != null) {
                         Integer tableTTLProp = desc.getColumnFamily(SchemaUtil.getEmptyColumnFamily(parent)).getTimeToLive();
                         if ((tableTTLProp != null) && (tableTTLProp != HConstants.FOREVER)) {
-                            throw new SQLExceptionInfo.Builder(SQLExceptionCode.CANNOT_SET_OR_ALTER_VIEW_TTL_FOR_TABLE_WITH_TTL)
+                            throw new SQLExceptionInfo.Builder(SQLExceptionCode.CANNOT_SET_OR_ALTER_PHOENIX_TTL_FOR_TABLE_WITH_TTL)
                                     .setMessage(String.format("table = %s, view = %s", parentPhysicalName, tableName ))
                                     .build()
                                     .buildException();
@@ -2078,7 +2078,7 @@ public class MetaDataClient {
                 }
 
                 if (tableType != VIEW) {
-                    throw new SQLExceptionInfo.Builder(SQLExceptionCode.VIEW_TTL_SUPPORTED_FOR_VIEWS_ONLY)
+                    throw new SQLExceptionInfo.Builder(SQLExceptionCode.PHOENIX_TTL_SUPPORTED_FOR_VIEWS_ONLY)
                             .setSchemaName(schemaName)
                             .setTableName(tableName)
                             .build()
@@ -2090,7 +2090,7 @@ public class MetaDataClient {
                 timestamp = TransactionUtil.getTableTimestamp(connection, transactionProvider != null, transactionProvider);
                 isImmutableRows = parent.isImmutableRows();
                 isAppendOnlySchema = parent.isAppendOnlySchema();
-                viewTTL = parent.getViewTTL();
+                phoenixTTL = parent.getPhoenixTTL();
 
                 // Index on view
                 // TODO: Can we support a multi-tenant index directly on a multi-tenant
@@ -2404,7 +2404,7 @@ public class MetaDataClient {
                         updateCacheFrequency = parent.getUpdateCacheFrequency();
                     }
 
-                    viewTTL = viewTTLProp == null ? parent.getViewTTL() : viewTTLProp;
+                    phoenixTTL = phoenixTTLProp == null ? parent.getPhoenixTTL() : phoenixTTLProp;
 
                     disableWAL = (disableWALProp == null ? parent.isWALDisabled() : disableWALProp);
                     defaultFamilyName = parent.getDefaultFamilyName() == null ? null : parent.getDefaultFamilyName().getString();
@@ -2764,8 +2764,8 @@ public class MetaDataClient {
                         .setIndexes(Collections.emptyList())
                         .setPhysicalNames(ImmutableList.of())
                         .setColumns(columns.values())
-                        .setViewTTL(VIEW_TTL_NOT_DEFINED)
-                        .setViewTTLHighWaterMark(MIN_VIEW_TTL_HWM)
+                        .setPhoenixTTL(PHOENIX_TTL_NOT_DEFINED)
+                        .setPhoenixTTLHighWaterMark(MIN_PHOENIX_TTL_HWM)
                         .build();
                 connection.addTable(table, MetaDataProtocol.MIN_TABLE_TIMESTAMP);
             }
@@ -2955,13 +2955,13 @@ public class MetaDataClient {
                 tableUpsert.setBoolean(28, useStatsForParallelizationProp);
             }
             tableUpsert.setInt(29, viewIndexIdType.getSqlType());
-            if (viewTTL == null || viewTTL == VIEW_TTL_NOT_DEFINED) {
+            if (phoenixTTL == null || phoenixTTL == PHOENIX_TTL_NOT_DEFINED) {
                 tableUpsert.setNull(30, Types.BIGINT);
                 tableUpsert.setNull(31, Types.BIGINT);
             }
             else {
-                tableUpsert.setLong(30, viewTTL);
-                tableUpsert.setLong(31, viewTTLHighWaterMark);
+                tableUpsert.setLong(30, phoenixTTL);
+                tableUpsert.setLong(31, phoenixTTLHighWaterMark);
             }
 
             tableUpsert.execute();
@@ -3091,9 +3091,9 @@ public class MetaDataClient {
                     .setPhysicalNames(physicalNames == null ?
                             ImmutableList.of() : ImmutableList.copyOf(physicalNames))
                     .setColumns(columns.values())
-                    .setViewTTL(viewTTL == null ? VIEW_TTL_NOT_DEFINED : viewTTL)
-                    .setViewTTLHighWaterMark(viewTTLHighWaterMark == null ? MIN_VIEW_TTL_HWM :
-                            viewTTLHighWaterMark)
+                    .setPhoenixTTL(phoenixTTL == null ? PHOENIX_TTL_NOT_DEFINED : phoenixTTL)
+                    .setPhoenixTTLHighWaterMark(phoenixTTLHighWaterMark == null ? MIN_PHOENIX_TTL_HWM :
+                            phoenixTTLHighWaterMark)
                     .setViewModifiedUpdateCacheFrequency(tableType ==  PTableType.VIEW &&
                             parent != null &&
                             parent.getUpdateCacheFrequency() != updateCacheFrequency)
@@ -3101,9 +3101,9 @@ public class MetaDataClient {
                             parent != null &&
                             parent.useStatsForParallelization()
                                     != useStatsForParallelizationProp)
-                    .setViewModifiedViewTTL(tableType ==  PTableType.VIEW &&
-                            parent != null && viewTTL != null &&
-                            parent.getViewTTL() != viewTTL)
+                    .setViewModifiedPhoenixTTL(tableType ==  PTableType.VIEW &&
+                            parent != null && phoenixTTL != null &&
+                            parent.getPhoenixTTL() != phoenixTTL)
                     .build();
             result = new MetaDataMutationResult(code, result.getMutationTime(), table, true);
             addTableToCache(result);
@@ -3479,18 +3479,18 @@ public class MetaDataClient {
                 metaPropertiesEvaluated.getAppendOnlySchema(),
                 metaPropertiesEvaluated.getImmutableStorageScheme(),
                 metaPropertiesEvaluated.getUseStatsForParallelization(),
-                metaPropertiesEvaluated.getViewTTL());
+                metaPropertiesEvaluated.getPhoenixTTL());
     }
 
-    private  long incrementTableSeqNum(PTable table, PTableType expectedType, int columnCountDelta, Boolean isTransactional, Long updateCacheFrequency, Long viewTTL) throws SQLException {
-        return incrementTableSeqNum(table, expectedType, columnCountDelta, isTransactional, null, updateCacheFrequency, null, null, null, null, -1L, null, null, null,viewTTL);
+    private  long incrementTableSeqNum(PTable table, PTableType expectedType, int columnCountDelta, Boolean isTransactional, Long updateCacheFrequency, Long phoenixTTL) throws SQLException {
+        return incrementTableSeqNum(table, expectedType, columnCountDelta, isTransactional, null, updateCacheFrequency, null, null, null, null, -1L, null, null, null,phoenixTTL);
     }
 
     private long incrementTableSeqNum(PTable table, PTableType expectedType, int columnCountDelta,
             Boolean isTransactional, TransactionFactory.Provider transactionProvider,
             Long updateCacheFrequency, Boolean isImmutableRows, Boolean disableWAL,
             Boolean isMultiTenant, Boolean storeNulls, Long guidePostWidth, Boolean appendOnlySchema,
-            ImmutableStorageScheme immutableStorageScheme, Boolean useStatsForParallelization, Long viewTTL)
+            ImmutableStorageScheme immutableStorageScheme, Boolean useStatsForParallelization, Long phoenixTTL)
             throws SQLException {
         String schemaName = table.getSchemaName().getString();
         String tableName = table.getTableName().getString();
@@ -3543,8 +3543,8 @@ public class MetaDataClient {
         if (useStatsForParallelization != null) {
             mutateBooleanProperty(tenantId, schemaName, tableName, USE_STATS_FOR_PARALLELIZATION, useStatsForParallelization);
         }
-        if (viewTTL != null) {
-            mutateLongProperty(tenantId, schemaName, tableName, VIEW_TTL, viewTTL);
+        if (phoenixTTL != null) {
+            mutateLongProperty(tenantId, schemaName, tableName, PHOENIX_TTL, phoenixTTL);
         }
         return seqNum;
     }
@@ -3858,12 +3858,12 @@ public class MetaDataClient {
 
                 if (!table.getIndexes().isEmpty() &&
                         (numPkColumnsAdded>0 || metaProperties.getNonTxToTx() ||
-                                metaPropertiesEvaluated.getUpdateCacheFrequency() != null || metaPropertiesEvaluated.getViewTTL() != null)) {
+                                metaPropertiesEvaluated.getUpdateCacheFrequency() != null || metaPropertiesEvaluated.getPhoenixTTL() != null)) {
                     for (PTable index : table.getIndexes()) {
                         incrementTableSeqNum(index, index.getType(), numPkColumnsAdded,
                                 metaProperties.getNonTxToTx() ? Boolean.TRUE : null,
                                 metaPropertiesEvaluated.getUpdateCacheFrequency(),
-                                metaPropertiesEvaluated.getViewTTL());
+                                metaPropertiesEvaluated.getPhoenixTTL());
                     }
                     tableMetaData.addAll(connection.getMutationState().toMutations(timeStamp).next().getSecond());
                     connection.rollback();
@@ -4785,8 +4785,8 @@ public class MetaDataClient {
                         metaProperties.setImmutableStorageSchemeProp((ImmutableStorageScheme)value);
                     } else if (propName.equalsIgnoreCase(USE_STATS_FOR_PARALLELIZATION)) {
                         metaProperties.setUseStatsForParallelizationProp((Boolean)value);
-                    } else if (propName.equalsIgnoreCase(VIEW_TTL)) {
-                        metaProperties.setViewTTL((Long) value);
+                    } else if (propName.equalsIgnoreCase(PHOENIX_TTL)) {
+                        metaProperties.setPhoenixTTL((Long) value);
                     }
                 }
                 // if removeTableProps is true only add the property if it is not an HTable or Phoenix Table property
@@ -4927,15 +4927,15 @@ public class MetaDataClient {
             }
         }
 
-        if (metaProperties.getViewTTL() != null) {
+        if (metaProperties.getPhoenixTTL() != null) {
             if (table.getType() != PTableType.VIEW) {
                 throw new SQLExceptionInfo.Builder(
-                        SQLExceptionCode.VIEW_TTL_SUPPORTED_FOR_VIEWS_ONLY)
+                        SQLExceptionCode.PHOENIX_TTL_SUPPORTED_FOR_VIEWS_ONLY)
                         .build()
                         .buildException();
             }
-            if (metaProperties.getViewTTL().longValue() != table.getViewTTL()) {
-                metaPropertiesEvaluated.setViewTTL(metaProperties.getViewTTL());
+            if (metaProperties.getPhoenixTTL().longValue() != table.getPhoenixTTL()) {
+                metaPropertiesEvaluated.setPhoenixTTL(metaProperties.getPhoenixTTL());
                 changingPhoenixTableProperty = true;
             }
         }
@@ -4956,7 +4956,7 @@ public class MetaDataClient {
         private ImmutableStorageScheme immutableStorageSchemeProp = null;
         private Boolean useStatsForParallelizationProp = null;
         private boolean nonTxToTx = false;
-        private Long viewTTL = null;
+        private Long phoenixTTL = null;
 
         public Boolean getImmutableRowsProp() {
             return isImmutableRowsProp;
@@ -5055,9 +5055,9 @@ public class MetaDataClient {
             this.nonTxToTx = nonTxToTx;
         }
 
-        public Long getViewTTL() { return viewTTL; }
+        public Long getPhoenixTTL() { return phoenixTTL; }
 
-        public void setViewTTL(Long viewTTL) { this.viewTTL = viewTTL; }
+        public void setPhoenixTTL(Long phoenixTTL) { this.phoenixTTL = phoenixTTL; }
     }
 
     class MetaPropertiesEvaluated{
@@ -5072,7 +5072,7 @@ public class MetaDataClient {
         private Boolean useStatsForParallelization = null;
         private Boolean isTransactional = null;
         private TransactionFactory.Provider transactionProvider = null;
-        private Long viewTTL = null;
+        private Long phoenixTTL = null;
 
         public Boolean getIsImmutableRows() {
             return isImmutableRows;
@@ -5161,9 +5161,9 @@ public class MetaDataClient {
         public void setTransactionProvider(TransactionFactory.Provider transactionProvider) {
             this.transactionProvider = transactionProvider;
         }
-        public Long getViewTTL() { return viewTTL; }
+        public Long getPhoenixTTL() { return phoenixTTL; }
 
-        public void setViewTTL(Long viewTTL) { this.viewTTL = viewTTL; }
+        public void setPhoenixTTL(Long phoenixTTL) { this.phoenixTTL = phoenixTTL; }
 
     }
 
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/schema/PTableImpl.java b/phoenix-core/src/main/java/org/apache/phoenix/schema/PTableImpl.java
index 571b284..b34559c 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/schema/PTableImpl.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/schema/PTableImpl.java
@@ -22,8 +22,8 @@ import static org.apache.phoenix.hbase.index.util.KeyValueBuilder.addQuietly;
 import static org.apache.phoenix.hbase.index.util.KeyValueBuilder.deleteQuietly;
 import static org.apache.phoenix.schema.SaltingUtil.SALTING_COLUMN;
 import static org.apache.phoenix.schema.types.PDataType.TRUE_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TTL_NOT_DEFINED;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.MIN_VIEW_TTL_HWM;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PHOENIX_TTL_NOT_DEFINED;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.MIN_PHOENIX_TTL_HWM;
 
 import java.io.IOException;
 import java.sql.DriverManager;
@@ -67,7 +67,6 @@ import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
 import org.apache.phoenix.hbase.index.util.KeyValueBuilder;
 import org.apache.phoenix.index.IndexMaintainer;
 import org.apache.phoenix.jdbc.PhoenixConnection;
-import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.jdbc.PhoenixStatement;
 import org.apache.phoenix.parse.ParseNode;
 import org.apache.phoenix.parse.SQLParser;
@@ -112,7 +111,7 @@ public class PTableImpl implements PTable {
     private static final Integer NO_SALTING = -1;
     private static final int VIEW_MODIFIED_UPDATE_CACHE_FREQUENCY_BIT_SET_POS = 0;
     private static final int VIEW_MODIFIED_USE_STATS_FOR_PARALLELIZATION_BIT_SET_POS = 1;
-    private static final int VIEW_MODIFIED_VIEW_TTL_BIT_SET_POS = 2;
+    private static final int VIEW_MODIFIED_PHOENIX_TTL_BIT_SET_POS = 2;
 
     private IndexMaintainer indexMaintainer;
     private ImmutableBytesWritable indexMaintainersPtr;
@@ -171,8 +170,8 @@ public class PTableImpl implements PTable {
     private final QualifierEncodingScheme qualifierEncodingScheme;
     private final EncodedCQCounter encodedCQCounter;
     private final Boolean useStatsForParallelization;
-    private final long viewTTL;
-    private final long viewTTLHighWaterMark;
+    private final long phoenixTTL;
+    private final long phoenixTTLHighWaterMark;
     private final BitSet viewModifiedPropSet;
 
     public static class Builder {
@@ -228,8 +227,8 @@ public class PTableImpl implements PTable {
         private QualifierEncodingScheme qualifierEncodingScheme;
         private EncodedCQCounter encodedCQCounter;
         private Boolean useStatsForParallelization;
-        private long viewTTL;
-        private long viewTTLHighWaterMark;
+        private long phoenixTTL;
+        private long phoenixTTLHighWaterMark;
 
         // Used to denote which properties a view has explicitly modified
         private BitSet viewModifiedPropSet = new BitSet(3);
@@ -519,18 +518,18 @@ public class PTableImpl implements PTable {
             return this;
         }
 
-        public Builder setViewTTL(long viewTTL) {
-            this.viewTTL = viewTTL;
+        public Builder setPhoenixTTL(long phoenixTTL) {
+            this.phoenixTTL = phoenixTTL;
             return this;
         }
 
-        public Builder setViewTTLHighWaterMark(long viewTTLHighWaterMark) {
-            this.viewTTLHighWaterMark = viewTTLHighWaterMark;
+        public Builder setPhoenixTTLHighWaterMark(long phoenixTTLHighWaterMark) {
+            this.phoenixTTLHighWaterMark = phoenixTTLHighWaterMark;
             return this;
         }
 
-        public Builder setViewModifiedViewTTL(boolean modified) {
-            this.viewModifiedPropSet.set(VIEW_MODIFIED_VIEW_TTL_BIT_SET_POS,
+        public Builder setViewModifiedPhoenixTTL(boolean modified) {
+            this.viewModifiedPropSet.set(VIEW_MODIFIED_PHOENIX_TTL_BIT_SET_POS,
                     modified);
             return this;
         }
@@ -805,8 +804,8 @@ public class PTableImpl implements PTable {
         this.qualifierEncodingScheme = builder.qualifierEncodingScheme;
         this.encodedCQCounter = builder.encodedCQCounter;
         this.useStatsForParallelization = builder.useStatsForParallelization;
-        this.viewTTL = builder.viewTTL;
-        this.viewTTLHighWaterMark = builder.viewTTLHighWaterMark;
+        this.phoenixTTL = builder.phoenixTTL;
+        this.phoenixTTLHighWaterMark = builder.phoenixTTLHighWaterMark;
         this.viewModifiedPropSet = builder.viewModifiedPropSet;
     }
 
@@ -875,9 +874,9 @@ public class PTableImpl implements PTable {
                 .setViewModifiedUseStatsForParallelization(table
                         .hasViewModifiedUseStatsForParallelization())
                 .setViewModifiedUpdateCacheFrequency(table.hasViewModifiedUpdateCacheFrequency())
-                .setViewModifiedViewTTL(table.hasViewModifiedViewTTL())
-                .setViewTTL(table.getViewTTL())
-                .setViewTTLHighWaterMark(table.getViewTTLHighWaterMark());
+                .setViewModifiedPhoenixTTL(table.hasViewModifiedPhoenixTTL())
+                .setPhoenixTTL(table.getPhoenixTTL())
+                .setPhoenixTTLHighWaterMark(table.getPhoenixTTLHighWaterMark());
     }
 
     @Override
@@ -1692,27 +1691,27 @@ public class PTableImpl implements PTable {
         if (table.hasUseStatsForParallelization()) {
             useStatsForParallelization = table.getUseStatsForParallelization();
         }
-        long viewTTL = VIEW_TTL_NOT_DEFINED;
-        if (table.hasViewTTL()) {
-            viewTTL = table.getViewTTL();
+        long phoenixTTL = PHOENIX_TTL_NOT_DEFINED;
+        if (table.hasPhoenixTTL()) {
+            phoenixTTL = table.getPhoenixTTL();
         }
-        long viewTTLHighWaterMark = MIN_VIEW_TTL_HWM;
-        if (table.hasViewTTLHighWaterMark()) {
-            viewTTLHighWaterMark = table.getViewTTLHighWaterMark();
+        long phoenixTTLHighWaterMark = MIN_PHOENIX_TTL_HWM;
+        if (table.hasPhoenixTTLHighWaterMark()) {
+            phoenixTTLHighWaterMark = table.getPhoenixTTLHighWaterMark();
         }
 
         // for older clients just use the value of the properties that are set on the view
         boolean viewModifiedUpdateCacheFrequency = true;
         boolean viewModifiedUseStatsForParallelization = true;
-        boolean viewModifiedViewTTL = true;
+        boolean viewModifiedPhoenixTTL = true;
         if (table.hasViewModifiedUpdateCacheFrequency()) {
             viewModifiedUpdateCacheFrequency = table.getViewModifiedUpdateCacheFrequency();
         }
         if (table.hasViewModifiedUseStatsForParallelization()) {
             viewModifiedUseStatsForParallelization = table.getViewModifiedUseStatsForParallelization();
         }
-        if (table.hasViewModifiedViewTTL()) {
-            viewModifiedViewTTL = table.getViewModifiedViewTTL();
+        if (table.hasViewModifiedPhoenixTTL()) {
+            viewModifiedPhoenixTTL = table.getViewModifiedPhoenixTTL();
         }
         try {
             return new PTableImpl.Builder()
@@ -1744,8 +1743,8 @@ public class PTableImpl implements PTable {
                     .setBaseColumnCount(baseColumnCount)
                     .setEncodedCQCounter(encodedColumnQualifierCounter)
                     .setUseStatsForParallelization(useStatsForParallelization)
-                    .setViewTTL(viewTTL)
-                    .setViewTTLHighWaterMark(viewTTLHighWaterMark)
+                    .setPhoenixTTL(phoenixTTL)
+                    .setPhoenixTTLHighWaterMark(phoenixTTLHighWaterMark)
                     .setExcludedColumns(ImmutableList.of())
                     .setTenantId(tenantId)
                     .setSchemaName(schemaName)
@@ -1762,7 +1761,7 @@ public class PTableImpl implements PTable {
                     .setColumns(columns)
                     .setViewModifiedUpdateCacheFrequency(viewModifiedUpdateCacheFrequency)
                     .setViewModifiedUseStatsForParallelization(viewModifiedUseStatsForParallelization)
-                    .setViewModifiedViewTTL(viewModifiedViewTTL)
+                    .setViewModifiedPhoenixTTL(viewModifiedPhoenixTTL)
                     .build();
         } catch (SQLException e) {
             throw new RuntimeException(e); // Impossible
@@ -1866,11 +1865,11 @@ public class PTableImpl implements PTable {
       if (table.useStatsForParallelization() != null) {
           builder.setUseStatsForParallelization(table.useStatsForParallelization());
       }
-      builder.setViewTTL(table.getViewTTL());
-      builder.setViewTTLHighWaterMark(table.getViewTTLHighWaterMark());
+      builder.setPhoenixTTL(table.getPhoenixTTL());
+      builder.setPhoenixTTLHighWaterMark(table.getPhoenixTTLHighWaterMark());
       builder.setViewModifiedUpdateCacheFrequency(table.hasViewModifiedUpdateCacheFrequency());
       builder.setViewModifiedUseStatsForParallelization(table.hasViewModifiedUseStatsForParallelization());
-      builder.setViewModifiedViewTTL(table.hasViewModifiedViewTTL());
+      builder.setViewModifiedPhoenixTTL(table.hasViewModifiedPhoenixTTL());
       return builder.build();
     }
 
@@ -1967,13 +1966,13 @@ public class PTableImpl implements PTable {
     }
 
     @Override
-    public long getViewTTL() {
-        return viewTTL;
+    public long getPhoenixTTL() {
+        return phoenixTTL;
     }
 
     @Override
-    public long getViewTTLHighWaterMark() {
-        return viewTTLHighWaterMark;
+    public long getPhoenixTTLHighWaterMark() {
+        return phoenixTTLHighWaterMark;
     }
 
     @Override public boolean hasViewModifiedUpdateCacheFrequency() {
@@ -1984,8 +1983,8 @@ public class PTableImpl implements PTable {
         return viewModifiedPropSet.get(VIEW_MODIFIED_USE_STATS_FOR_PARALLELIZATION_BIT_SET_POS);
     }
 
-    @Override public boolean hasViewModifiedViewTTL() {
-        return viewModifiedPropSet.get(VIEW_MODIFIED_VIEW_TTL_BIT_SET_POS);
+    @Override public boolean hasViewModifiedPhoenixTTL() {
+        return viewModifiedPropSet.get(VIEW_MODIFIED_PHOENIX_TTL_BIT_SET_POS);
     }
 
     private static final class KVColumnFamilyQualifier {
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/util/ViewUtil.java b/phoenix-core/src/main/java/org/apache/phoenix/util/ViewUtil.java
index bc01d16..57bbc92 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/util/ViewUtil.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/util/ViewUtil.java
@@ -79,7 +79,7 @@ import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAM
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CHILD_LINK_NAME_BYTES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_TYPE_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TTL_BYTES;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PHOENIX_TTL_BYTES;
 import static org.apache.phoenix.schema.PTableImpl.getColumnsToClone;
 import static org.apache.phoenix.util.SchemaUtil.getVarChars;
 
@@ -616,7 +616,7 @@ public class ViewUtil {
             PTable parent, ExtendedCellBuilder extendedCellBuilder) {
         byte[] parentUpdateCacheFreqBytes = null;
         byte[] parentUseStatsForParallelizationBytes = null;
-        byte[] parentViewTTLBytes = null;
+        byte[] parentPhoenixTTLBytes = null;
         if (parent != null) {
             parentUpdateCacheFreqBytes = new byte[PLong.INSTANCE.getByteSize()];
             PLong.INSTANCE.getCodec().encodeLong(parent.getUpdateCacheFrequency(),
@@ -625,9 +625,9 @@ public class ViewUtil {
                 parentUseStatsForParallelizationBytes =
                         PBoolean.INSTANCE.toBytes(parent.useStatsForParallelization());
             }
-            parentViewTTLBytes = new byte[PLong.INSTANCE.getByteSize()];
-            PLong.INSTANCE.getCodec().encodeLong(parent.getViewTTL(),
-                    parentViewTTLBytes, 0);
+            parentPhoenixTTLBytes = new byte[PLong.INSTANCE.getByteSize()];
+            PLong.INSTANCE.getCodec().encodeLong(parent.getPhoenixTTL(),
+                    parentPhoenixTTLBytes, 0);
         }
         for (Mutation m: tableMetaData) {
             if (m instanceof Put) {
@@ -645,9 +645,9 @@ public class ViewUtil {
                         MetaDataEndpointImpl.VIEW_MODIFIED_PROPERTY_BYTES);
                 MetaDataUtil.conditionallyAddTagsToPutCells((Put)m,
                         PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES,
-                        PhoenixDatabaseMetaData.VIEW_TTL_BYTES,
+                        PhoenixDatabaseMetaData.PHOENIX_TTL_BYTES,
                         extendedCellBuilder,
-                        parentViewTTLBytes,
+                        parentPhoenixTTLBytes,
                         MetaDataEndpointImpl.VIEW_MODIFIED_PROPERTY_BYTES);
             }
 
diff --git a/phoenix-protocol/src/main/PTable.proto b/phoenix-protocol/src/main/PTable.proto
index d77a583..37fdd1d 100644
--- a/phoenix-protocol/src/main/PTable.proto
+++ b/phoenix-protocol/src/main/PTable.proto
@@ -106,9 +106,9 @@ message PTable {
   optional int32 viewIndexIdType = 39 [default = 5];
   optional bool viewModifiedUpdateCacheFrequency = 40;
   optional bool viewModifiedUseStatsForParallelization = 41;
-  optional int64 viewTTL = 42;
-  optional int64 viewTTLHighWaterMark = 43;
-  optional bool viewModifiedViewTTL = 44;
+  optional int64 phoenixTTL = 42;
+  optional int64 phoenixTTLHighWaterMark = 43;
+  optional bool viewModifiedPhoenixTTL = 44;
 }
 
 message EncodedCQCounter {
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/jdbc/PhoenixDatabaseMetaData.java b/phoenix-core/src/main/java/org/apache/phoenix/jdbc/PhoenixDatabaseMetaData.java
index c65026f..69ad053 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/jdbc/PhoenixDatabaseMetaData.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/jdbc/PhoenixDatabaseMetaData.java
@@ -373,15 +373,15 @@ public class PhoenixDatabaseMetaData implements DatabaseMetaData {
     public static final String USE_STATS_FOR_PARALLELIZATION = "USE_STATS_FOR_PARALLELIZATION";
     public static final byte[] USE_STATS_FOR_PARALLELIZATION_BYTES = Bytes.toBytes(USE_STATS_FOR_PARALLELIZATION);
 
-    // The view ttl property will hold the duration after which rows will be marked as expired.
-    public static final long VIEW_TTL_NOT_DEFINED = 0L;
-    public static final String VIEW_TTL = "VIEW_TTL";
-    public static final byte[] VIEW_TTL_BYTES = Bytes.toBytes(VIEW_TTL);
-    // The view ttl high watermark if set indicates the timestamp used for determining the expired rows.
+    // The PHOENIX_TTL property will hold the duration after which rows will be marked as expired.
+    public static final long PHOENIX_TTL_NOT_DEFINED = 0L;
+    public static final String PHOENIX_TTL = "PHOENIX_TTL";
+    public static final byte[] PHOENIX_TTL_BYTES = Bytes.toBytes(PHOENIX_TTL);
+    // The phoenix ttl high watermark if set indicates the timestamp used for determining the expired rows.
     // otherwise the now() - ttl-duration is the timestamp used.
-    public static final long MIN_VIEW_TTL_HWM = 0L;
-    public static final String VIEW_TTL_HWM = "VIEW_TTL_HWM";
-    public static final byte[] VIEW_TTL_HWM_BYTES = Bytes.toBytes(VIEW_TTL_HWM);
+    public static final long MIN_PHOENIX_TTL_HWM = 0L;
+    public static final String PHOENIX_TTL_HWM = "PHOENIX_TTL_HWM";
+    public static final byte[] PHOENIX_TTL_HWM_BYTES = Bytes.toBytes(PHOENIX_TTL_HWM);
 
     public static final String SYSTEM_CHILD_LINK_TABLE = "CHILD_LINK";
     public static final String SYSTEM_CHILD_LINK_NAME = SchemaUtil.getTableName(SYSTEM_CATALOG_SCHEMA, SYSTEM_CHILD_LINK_TABLE);
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/schema/PTable.java b/phoenix-core/src/main/java/org/apache/phoenix/schema/PTable.java
index c3461a8..941e422 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/schema/PTable.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/schema/PTable.java
@@ -802,19 +802,19 @@ public interface PTable extends PMetaDataEntity {
     boolean hasViewModifiedUseStatsForParallelization();
 
     /**
      * @return The VIEW_TTL duration associated with the view.
      */
-    long getViewTTL();
+    long getPhoenixTTL();
 
     /**
      * @return The VIEW_TTL high water mark timestamp associated with the view.
      */
-    long getViewTTLHighWaterMark();
+    long getPhoenixTTLHighWaterMark();
 
     /**
-     * @return If the view has overridden the TTL set at the parent view level.
+     * @return If the view has overridden the TTL set at the parent entity level.
      */
-    boolean hasViewModifiedViewTTL();
+    boolean hasViewModifiedPhoenixTTL();
 
     /**
      * Class to help track encoded column qualifier counters per column family.
@@ -802,19 +802,19 @@ public interface PTable extends PMetaDataEntity {
 
     /**
-     * @return The VIEW_TTL duration associated with the view.
+     * @return The PHOENIX_TTL duration associated with the entity.
      */
@@ -802,19 +802,19 @@ public interface PTable extends PMetaDataEntity {
 
     /**
-     * @return The VIEW_TTL high water mark timestamp associated with the view.
+     * @return The PHOENIX_TTL high water mark timestamp associated with the entity.
      */
diff --git a/phoenix-core/src/main/java/org/apache/phoenix/schema/TableProperty.java b/phoenix-core/src/main/java/org/apache/phoenix/schema/TableProperty.java
index 1ebba0d..7853576 100644
--- a/phoenix-core/src/main/java/org/apache/phoenix/schema/TableProperty.java
+++ b/phoenix-core/src/main/java/org/apache/phoenix/schema/TableProperty.java
@@ -24,7 +24,7 @@ import static org.apache.phoenix.exception.SQLExceptionCode.DEFAULT_COLUMN_FAMIL
 import static org.apache.phoenix.exception.SQLExceptionCode.SALT_ONLY_ON_CREATE_TABLE;
 import static org.apache.phoenix.exception.SQLExceptionCode.VIEW_WITH_PROPERTIES;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.DEFAULT_COLUMN_FAMILY_NAME;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_TTL_NOT_DEFINED;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PHOENIX_TTL_NOT_DEFINED;
 
 import java.sql.SQLException;
 import java.util.Map;
@@ -241,9 +241,9 @@ public enum TableProperty {
         }
     },
 
-    VIEW_TTL(PhoenixDatabaseMetaData.VIEW_TTL, true, true, true) {
+    PHOENIX_TTL(PhoenixDatabaseMetaData.PHOENIX_TTL, true, true, true) {
         /**
          * VIEW_TTL can take any values ranging between 0 < VIEW_TTL <= HConstants.LATEST_TIMESTAMP.
          * special values :-
          * NONE or 0L => Not Defined.
          * FOREVER => HConstants.LATEST_TIMESTAMP
@@ -258,7 +258,7 @@ public enum TableProperty {
                 if ("FOREVER".equalsIgnoreCase(strValue)) {
                     return HConstants.LATEST_TIMESTAMP;
                 } else if ("NONE".equalsIgnoreCase(strValue)) {
-                    return VIEW_TTL_NOT_DEFINED;
+                    return PHOENIX_TTL_NOT_DEFINED;
                 }
             } else {
                 return value == null ? null : ((Number) value).longValue();
@@ -268,7 +268,7 @@ public enum TableProperty {
 
         @Override
         public Object getPTableValue(PTable table) {
-            return table.getViewTTL();
+            return table.getPhoenixTTL();
         }
     }
     ;
@@ -241,9 +241,9 @@ public enum TableProperty {
         /**
-         * VIEW_TTL can take any values ranging between 0 < VIEW_TTL <= HConstants.LATEST_TIMESTAMP.
+         * PHOENIX_TTL can take any values ranging between 0 < PHOENIX_TTL <= HConstants.LATEST_TIMESTAMP.
          * special values :-
          * NONE or 0L => Not Defined.